package betterquesting.client.gui2.editors;

import betterquesting.api.client.importers.IImporter;
import betterquesting.api.misc.ICallback;
import betterquesting.api2.client.gui.GuiScreenCanvas;
import betterquesting.api2.client.gui.controls.PanelButton;
import betterquesting.api2.client.gui.controls.PanelButtonStorage;
import betterquesting.api2.client.gui.events.IPEventListener;
import betterquesting.api2.client.gui.events.PEventBroadcaster;
import betterquesting.api2.client.gui.events.PanelEvent;
import betterquesting.api2.client.gui.events.types.PEventButton;
import betterquesting.api2.client.gui.misc.GuiAlign;
import betterquesting.api2.client.gui.misc.GuiPadding;
import betterquesting.api2.client.gui.misc.GuiRectangle;
import betterquesting.api2.client.gui.misc.GuiTransform;
import betterquesting.api2.client.gui.panels.CanvasEmpty;
import betterquesting.api2.client.gui.panels.CanvasTextured;
import betterquesting.api2.client.gui.panels.bars.PanelVScrollBar;
import betterquesting.api2.client.gui.panels.content.PanelLine;
import betterquesting.api2.client.gui.panels.content.PanelTextBox;
import betterquesting.api2.client.gui.panels.lists.CanvasScrolling;
import betterquesting.api2.client.gui.themes.presets.PresetColor;
import betterquesting.api2.client.gui.themes.presets.PresetLine;
import betterquesting.api2.client.gui.themes.presets.PresetTexture;
import betterquesting.api2.utils.QuestTranslation;
import betterquesting.client.importers.ImportedQuestLines;
import betterquesting.client.importers.ImportedQuests;
import betterquesting.client.importers.ImporterRegistry;
import betterquesting.network.handlers.NetImport;
import java.io.File;
import java.util.List;
import net.minecraft.client.gui.GuiScreen;
import org.lwjgl.input.Keyboard;

/* loaded from: betterquesting_client_gui2_editors.jar:betterquesting/client/gui2/editors/GuiImporters.class */
public class GuiImporters extends GuiScreenCanvas implements IPEventListener, ICallback<File[]> {
    private PanelTextBox impName;
    private CanvasScrolling impDescCV;
    private PanelTextBox impDescTX;
    private PanelButtonStorage<IImporter> impBtn;
    private IImporter lastImport;

    public GuiImporters(GuiScreen parent) {
        super(parent);
    }

    public void initPanel() {
        super.initPanel();
        PEventBroadcaster.INSTANCE.register(this, PEventButton.class);
        Keyboard.enableRepeatEvents(true);
        CanvasTextured cvBackground = new CanvasTextured(new GuiTransform(GuiAlign.FULL_BOX, new GuiPadding(0, 0, 0, 0), 0), PresetTexture.PANEL_MAIN.getTexture());
        addPanel(cvBackground);
        PanelTextBox panTxt = new PanelTextBox(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 16, 0, -32), 0), QuestTranslation.translate("betterquesting.title.importers", new Object[0])).setAlignment(1);
        panTxt.setColor(PresetColor.TEXT_HEADER.getColor());
        cvBackground.addPanel(panTxt);
        cvBackground.addPanel(new PanelButton(new GuiTransform(GuiAlign.BOTTOM_CENTER, -100, -16, 200, 16, 0), 0, QuestTranslation.translate("gui.back", new Object[0])));
        CanvasScrolling cvImports = new CanvasScrolling(new GuiTransform(GuiAlign.HALF_LEFT, new GuiPadding(16, 32, 16, 24), 0));
        cvBackground.addPanel(cvImports);
        int width = cvImports.getTransform().getWidth();
        List<IImporter> impList = ImporterRegistry.INSTANCE.getImporters();
        for (int i = 0; i < impList.size(); i++) {
            IImporter imp = impList.get(i);
            cvImports.addPanel(new PanelButtonStorage(new GuiRectangle(0, i * 16, width, 16, 0), 1, QuestTranslation.translate(imp.getUnlocalisedName(), new Object[0]), imp));
        }
        PanelVScrollBar scReq = new PanelVScrollBar(new GuiTransform(GuiAlign.RIGHT_EDGE, new GuiPadding(0, 0, -8, 0), 0));
        cvBackground.addPanel(scReq);
        scReq.getTransform().setParent(cvImports.getTransform());
        cvImports.setScrollDriverY(scReq);
        CanvasEmpty cvRight = new CanvasEmpty(new GuiTransform(GuiAlign.HALF_RIGHT, new GuiPadding(8, 32, 16, 24), 0));
        cvBackground.addPanel(cvRight);
        this.impName = new PanelTextBox(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 0, 0, -16), 0), "").setAlignment(1).setColor(PresetColor.TEXT_MAIN.getColor());
        cvRight.addPanel(this.impName);
        this.impDescCV = new CanvasScrolling(new GuiTransform(GuiAlign.FULL_BOX, new GuiPadding(0, 16, 8, 24), 0));
        cvRight.addPanel(this.impDescCV);
        PanelVScrollBar scDesc = new PanelVScrollBar(new GuiTransform(GuiAlign.RIGHT_EDGE, new GuiPadding(0, 0, -8, 0), 0));
        cvRight.addPanel(scDesc);
        scDesc.getTransform().setParent(this.impDescCV.getTransform());
        this.impDescCV.setScrollDriverY(scDesc);
        int width2 = this.impDescCV.getTransform().getWidth();
        this.impDescTX = new PanelTextBox(new GuiRectangle(0, 0, width2, 16, 0), "", true).setColor(PresetColor.TEXT_MAIN.getColor());
        this.impDescCV.addPanel(this.impDescTX);
        this.impBtn = new PanelButtonStorage<>(new GuiTransform(GuiAlign.BOTTOM_EDGE, new GuiPadding(0, -16, 0, 0), 0), 2, QuestTranslation.translate("betterquesting.btn.import", new Object[0]), (Object) null);
        this.impBtn.setActive(false);
        cvRight.addPanel(this.impBtn);
        GuiTransform guiTransform = new GuiTransform(GuiAlign.TOP_CENTER, 0, 32, 0, 0, 0);
        guiTransform.setParent(cvBackground.getTransform());
        GuiTransform guiTransform2 = new GuiTransform(GuiAlign.BOTTOM_CENTER, 0, -24, 0, 0, 0);
        guiTransform2.setParent(cvBackground.getTransform());
        PanelLine paLine0 = new PanelLine(guiTransform, guiTransform2, PresetLine.GUI_DIVIDER.getLine(), 1, PresetColor.GUI_DIVIDER.getColor(), 1);
        cvBackground.addPanel(paLine0);
    }

    public void onPanelEvent(PanelEvent event) {
        if (event instanceof PEventButton) {
            onButtonPress((PEventButton) event);
        }
    }

    private void onButtonPress(PEventButton event) {
        PanelButtonStorage button = event.getButton();
        if (button.getButtonID() == 0) {
            this.field_146297_k.func_147108_a(this.parent);
            return;
        }
        if (button.getButtonID() != 1) {
            if (button.getButtonID() == 2) {
                this.lastImport = (IImporter) button.getStoredValue();
                this.field_146297_k.func_147108_a(new GuiFileBrowser(this, this, new File(".").getAbsoluteFile().getParentFile(), this.lastImport.getFileFilter()));
                return;
            }
            return;
        }
        IImporter imp = (IImporter) button.getStoredValue();
        this.impName.setText(QuestTranslation.translate(imp.getUnlocalisedName(), new Object[0]));
        this.impDescTX.setText(QuestTranslation.translate(imp.getUnlocalisedDescription(), new Object[0]));
        this.impDescCV.refreshScrollBounds();
        this.impBtn.setStoredValue(imp);
        this.impBtn.setActive(true);
    }

    public void setValue(File[] files) {
        if (files == null || files.length <= 0 || this.lastImport == null) {
            return;
        }
        ImportedQuests questDB = new ImportedQuests();
        ImportedQuestLines importedQuestLines = new ImportedQuestLines();
        this.lastImport.loadFiles(questDB, importedQuestLines, files);
        if (questDB.size() > 0 || importedQuestLines.size() > 0) {
            NetImport.sendImport(questDB, importedQuestLines);
            this.field_146297_k.func_147108_a(this.parent);
        }
    }
}
